@@ -336,7 +336,6 @@ class ServiceInstanceManager(object):
                 name, description)['security_group']
             for protocol, ports in const.SERVICE_INSTANCE_SECGROUP_DATA:
                 self.network_helper.neutron_api.security_group_rule_create(
-                    context,
                     parent_group_id=sg['id'],
                     ip_protocol=protocol,
                     from_port=ports[0],
@@ -484,12 +483,14 @@ class ServiceInstanceManager(object):
         """Returns ID of service image for service vm creating."""
         service_image_name = self.get_config_option("service_image_name")
         images = [image.id for image in self.compute_api.image_list(context)
-                  if image.name == service_image_name]
+                  if image.name == service_image_name
+                  and image.status == 'active']
         if len(images) == 1:
             return images[0]
         elif not images:
             raise exception.ServiceInstanceException(
-                _("Image with name '%s' not found.") % service_image_name)
+                _("Image with name '%s' was not found or is not in "
+                  "'active' state.") % service_image_name)
         else:
             raise exception.ServiceInstanceException(
                 _("Found more than one image by name '%s'.") %
@@ -903,6 +904,8 @@ class NeutronNetworkHelper(BaseNetworkhelper):
         and setting up required network devices.
         """
         if self.use_service_network:
+            LOG.debug("Plugging service instance into service network %s.",
+                      self.service_network_id)
             port = self._get_service_port(
                 self.service_network_id, None, 'manila-share')
             port = self._add_fixed_ips_to_service_port(port)
@@ -911,6 +914,8 @@ class NeutronNetworkHelper(BaseNetworkhelper):
             self._plug_interface_in_host(interface_name, device, port)
 
         if self.use_admin_port:
+            LOG.debug("Plugging service instance into admin network %s.",
+                      self.admin_network_id)
             port = self._get_service_port(
                 self.admin_network_id, self.admin_subnet_id,
                 'manila-admin-share')
@@ -925,6 +930,8 @@ class NeutronNetworkHelper(BaseNetworkhelper):
                         external=True)
     def _plug_interface_in_host(self, interface_name, device, port):
 
+        LOG.debug("Plug interface into host - interface_name: %s, "
+                  "device: %s, port: %s", interface_name, device, port)
         self.vif_driver.plug(interface_name, port['id'], port['mac_address'])
         ip_cidrs = []
         for fixed_ip in port['fixed_ips']:
@@ -985,7 +992,8 @@ class NeutronNetworkHelper(BaseNetworkhelper):
         elif not ports:
             port = self.neutron_api.create_port(
                 self.admin_project_id, network_id, subnet_id=subnet_id,
-                device_id=device_id, device_owner='manila:share', host_id=host)
+                device_id=device_id, device_owner='manila:share', host_id=host,
+                port_security_enabled=False)
         else:
             port = ports[0]
         return port
